import {
  geoPath,
  geoNaturalEarth1,
  zoom,
  event
} from 'd3';

const projection = geoNaturalEarth1();
const pathGenerator = geoPath().projection(projection);

export const coloroplethMap = (selection, props) => {
  const {
    features,
    colorValue,
    colorScale,
    selectedColorValue
  } = props;
  
  const gUpdate = selection.selectAll('g').data([null]);
  const gEnter = gUpdate.enter().append('g');
  const g = gUpdate.merge(gEnter);
  
  gEnter
    .append('path')
    	.attr('class', 'sphere')
    	.attr('d', pathGenerator({type: 'Sphere'}))
		.merge(gUpdate.select('.sphere'))
  		.attr('opacity', selectedColorValue ? 0.5 : 1)
  
  selection.call(zoom().on('zoom', () => {
      g.attr('transform', event.transform);
    }));

  const countryPaths = g.selectAll('.country')
  	.data(features);
  const countryPathsEnter = countryPaths
    .enter().append('path')
      .attr('class', 'country')
  
  countryPathsEnter
  	.merge(countryPaths)
  		.attr('d', pathGenerator)
  		.attr('fill', d => colorScale(colorValue(d)))
  		.attr('opacity',
           d => colorValue(d) === selectedColorValue || !selectedColorValue
           ? 1
           : 0.2)
  		.classed('highlighted', d => colorValue(d) === selectedColorValue);
      
      
  countryPathsEnter
    .append('title')
      .text(d => d.properties.name + ': ' + colorValue(d));
}